@@ -1,12 +1,13 @@
 from itertools import product
 import math
 from numbers import Integral, Number
-from operator import getitem, itemgetter
+from operator import add, getitem, itemgetter
 import warnings
 import functools
+import bisect
 
 import numpy as np
-from toolz import memoize, merge, pluck, concat
+from toolz import memoize, merge, pluck, concat, accumulate
 
 from .. import core
 from ..highlevelgraph import HighLevelGraph
@@ -400,7 +401,7 @@ def _slice_1d(dim_shape, lengths, index):
 
     if isinstance(index, Integral):
         # use right-side search to be consistent with previous result
-        i = chunk_boundaries.searchsorted(index, side="right")
+        i = bisect.bisect_right(chunk_boundaries, index)
         if i > 0:
             # the very first chunk has no relative shift
             ind = index - chunk_boundaries[i - 1]
@@ -430,8 +431,8 @@ def _slice_1d(dim_shape, lengths, index):
 
     d = dict()
     if step > 0:
-        istart = chunk_boundaries.searchsorted(start, side="right")
-        istop = chunk_boundaries.searchsorted(stop, side="left")
+        istart = bisect.bisect_right(chunk_boundaries, start)
+        istop = bisect.bisect_left(chunk_boundaries, stop)
 
         # the bound is not exactly tight; make it tighter?
         istop = min(istop + 1, len(lengths))
@@ -452,8 +453,8 @@ def _slice_1d(dim_shape, lengths, index):
     else:
         rstart = start  # running start
 
-        istart = chunk_boundaries.searchsorted(start, side="left")
-        istop = chunk_boundaries.searchsorted(stop, side="right")
+        istart = bisect.bisect_left(chunk_boundaries, start)
+        istop = bisect.bisect_right(chunk_boundaries, stop)
 
         # the bound is not exactly tight; make it tighter?
         istart = min(istart + 1, len(chunk_boundaries) - 1)
@@ -1201,26 +1202,22 @@ class _HashIdWrapper(object):
 
 
 @functools.lru_cache()
-def _cumsum(seq):
+def _cumsum(seq, initial_zero):
     if isinstance(seq, _HashIdWrapper):
-        return _cumsum(seq.wrapped)
-    seq = np.array(seq)
-    dtype = np.int64 if np.issubdtype(seq.dtype, np.integer) else seq.dtype
-    out = np.empty(len(seq) + 1, dtype)
-    out[0] = 0
-    np.cumsum(seq, out=out[1:], dtype=dtype)
-    return out
+        seq = seq.wrapped
+    if initial_zero:
+        return tuple(accumulate(add, seq, 0))
+    else:
+        return tuple(accumulate(add, seq))
 
 
 def cached_cumsum(seq, initial_zero=False):
-    """Compute :meth:`np.cumsum` with caching.
+    """Compute :meth:`toolz.accumulate` with caching.
 
     Caching is by the identify of `seq` rather than the value. It is thus
     important that `seq` is a tuple of immutable objects, and this function
-    is intended for use where `seq` is a value that will persist.
-
-    The result has type int64 if the sequence contains integers, and
-    otherwise the type of ``np.array(seq)``.
+    is intended for use where `seq` is a value that will persist (generally
+    block sizes).
 
     Parameters
     ----------
@@ -1228,15 +1225,16 @@ def cached_cumsum(seq, initial_zero=False):
         Values to cumulatively sum.
     initial_zero : bool, optional
         If true, the return value is prefixed with a zero.
+
+    Returns
+    -------
+    tuple
     """
     if isinstance(seq, tuple):
         # Look up by identity first, to avoid a linear-time __hash__
         # if we've seen this tuple object before.
-        result = _cumsum(_HashIdWrapper(seq))
+        result = _cumsum(_HashIdWrapper(seq), initial_zero)
     else:
         # Construct a temporary tuple, and look up by value.
-        result = _cumsum(tuple(seq))
-
-    if not initial_zero:
-        result = result[1:]
+        result = _cumsum(tuple(seq), initial_zero)
     return result
