@@ -21,6 +21,6 @@ except ImportError as e:
         "Dask bag requirements are not installed.\n\n"
         "Please either conda or pip install as follows:\n\n"
         "  conda install dask               # either conda install\n"
-        "  pip install dask[bag] --upgrade  # or pip install"
+        "  python -m pip install dask[bag] --upgrade  # or python -m pip install"
     )
     raise ImportError(str(e) + "\n\n" + msg)
