@@ -157,6 +157,7 @@ class Blockwise(Mapping):
     new_axes: Dict
         New index dimensions that may have been created, and their extent
 
+
     See Also
     --------
     dask.blockwise.blockwise
@@ -183,6 +184,9 @@ class Blockwise(Mapping):
         self.concatenate = concatenate
         self.new_axes = new_axes or {}
 
+    def __repr__(self):
+        return "Blockwise<{} -> {}>".format(self.indices, self.output)
+
     @property
     def _dict(self):
         if hasattr(self, "_cached_dict"):
@@ -577,6 +581,10 @@ def rewrite_blockwise(inputs):
     --------
     optimize_blockwise
     """
+    if len(inputs) == 1:
+        # Fast path: if there's only one input we can just use it as-is.
+        return inputs[0]
+
     inputs = {inp.output: inp for inp in inputs}
     dependencies = {
         inp.output: {d for d, v in inp.indices if v is not None and d in inputs}
@@ -643,15 +651,14 @@ def rewrite_blockwise(inputs):
 
             # Bump new inputs up in list
             sub = {}
+            # Map from (id(key), inds or None) -> index in indices. Used to deduplicate indices.
+            index_map = {(id(k), inds): n for n, (k, inds) in enumerate(indices)}
             for i, index in enumerate(new_indices):
-                try:
-                    contains = index in indices
-                except (ValueError, TypeError):
-                    contains = False
-
-                if contains:  # use old inputs if available
-                    sub[blockwise_token(i)] = blockwise_token(indices.index(index))
+                id_key = (id(index[0]), index[1])
+                if id_key in index_map:  # use old inputs if available
+                    sub[blockwise_token(i)] = blockwise_token(index_map[id_key])
                 else:
+                    index_map[id_key] = len(indices)
                     sub[blockwise_token(i)] = blockwise_token(len(indices))
                     indices.append(index)
             new_dsk = subs(inputs[dep].dsk, sub)
@@ -659,8 +666,6 @@ def rewrite_blockwise(inputs):
             # indices.extend(new_indices)
             dsk.update(new_dsk)
 
-    indices = [(a, tuple(b) if isinstance(b, list) else b) for a, b in indices]
-
     # De-duplicate indices like [(a, ij), (b, i), (a, ij)] -> [(a, ij), (b, i)]
     # Make sure that we map everything else appropriately as we remove inputs
     new_indices = []
