@@ -51,7 +51,7 @@ from ..highlevelgraph import HighLevelGraph
 # operates on matching partitions of frame-like objects passed as varargs.
 #
 # After the initial chunk step, the passed index is implicitly passed along to
-# subsequent operations as the index of the parittions. Groupby operations on
+# subsequent operations as the index of the partitions. Groupby operations on
 # the individual partitions can then access the index via the ``levels``
 # parameter of the ``groupby`` function. The correct argument is determined by
 # the ``_determine_levels`` function.
@@ -126,7 +126,7 @@ def _groupby_raise_unaligned(df, **kwargs):
     """Groupby, but raise if df and `by` key are unaligned.
 
     Pandas supports grouping by a column that doesn't align with the input
-    frame/series/index. However, the reindexing this causes doesn't seem to be
+    frame/series/index. However, the reindexing does not seem to be
     threadsafe, and can result in incorrect results. Since grouping by an
     unaligned key is generally a bad idea, we just error loudly in dask.
 
@@ -274,9 +274,11 @@ class Aggregation(object):
         self.__name__ = name
 
 
-def _groupby_aggregate(df, aggfunc=None, levels=None, dropna=None, **kwargs):
+def _groupby_aggregate(
+    df, aggfunc=None, levels=None, dropna=None, sort=False, **kwargs
+):
     dropna = {"dropna": dropna} if dropna is not None else {}
-    return aggfunc(df.groupby(level=levels, sort=False, **dropna), **kwargs)
+    return aggfunc(df.groupby(level=levels, sort=sort, **dropna), **kwargs)
 
 
 def _apply_chunk(df, *index, dropna=None, **kwargs):
@@ -298,27 +300,27 @@ def _var_chunk(df, *index):
         df = df.to_frame()
 
     df = df.copy()
-    cols = df._get_numeric_data().columns
 
     g = _groupby_raise_unaligned(df, by=index)
     x = g.sum()
 
     n = g[x.columns].count().rename(columns=lambda c: (c, "-count"))
 
+    cols = x.columns
     df[cols] = df[cols] ** 2
+
     g2 = _groupby_raise_unaligned(df, by=index)
     x2 = g2.sum().rename(columns=lambda c: (c, "-x2"))
 
-    x2.index = x.index
     return concat([x, x2, n], axis=1)
 
 
-def _var_combine(g, levels):
-    return g.groupby(level=levels, sort=False).sum()
+def _var_combine(g, levels, sort=False):
+    return g.groupby(level=levels, sort=sort).sum()
 
 
-def _var_agg(g, levels, ddof):
-    g = g.groupby(level=levels, sort=False).sum()
+def _var_agg(g, levels, ddof, sort=False):
+    g = g.groupby(level=levels, sort=sort).sum()
     nc = len(g.columns)
     x = g[g.columns[: nc // 3]]
     # chunks columns are tuples (value, name), so we just keep the value part
@@ -332,6 +334,7 @@ def _var_agg(g, levels, ddof):
     result /= div
     result[(n - ddof) == 0] = np.nan
     assert is_dataframe_like(result)
+    result[result < 0] = 0  # avoid rounding errors that take us to zero
     return result
 
 
@@ -428,7 +431,7 @@ def _cov_chunk(df, *index):
     return (x, mul, n, col_mapping)
 
 
-def _cov_agg(_t, levels, ddof, std=False):
+def _cov_agg(_t, levels, ddof, std=False, sort=False):
     sums = []
     muls = []
     counts = []
@@ -443,8 +446,8 @@ def _cov_agg(_t, levels, ddof, std=False):
         counts.append(n)
         col_mapping = col_mapping
 
-    total_sums = concat(sums).groupby(level=levels, sort=False).sum()
-    total_muls = concat(muls).groupby(level=levels, sort=False).sum()
+    total_sums = concat(sums).groupby(level=levels, sort=sort).sum()
+    total_muls = concat(muls).groupby(level=levels, sort=sort).sum()
     total_counts = concat(counts).groupby(level=levels).sum()
     result = (
         concat([total_sums, total_muls, total_counts], axis=1)
@@ -522,8 +525,8 @@ def _drop_duplicates_rename(df):
     return df.drop_duplicates().rename_axis(names, copy=False)
 
 
-def _nunique_df_combine(df, levels):
-    result = df.groupby(level=levels, sort=False).apply(_drop_duplicates_rename)
+def _nunique_df_combine(df, levels, sort=False):
+    result = df.groupby(level=levels, sort=sort).apply(_drop_duplicates_rename)
 
     if isinstance(levels, list):
         result.index = pd.MultiIndex.from_arrays(
@@ -535,8 +538,8 @@ def _nunique_df_combine(df, levels):
     return result
 
 
-def _nunique_df_aggregate(df, levels, name):
-    return df.groupby(level=levels, sort=False)[name].nunique()
+def _nunique_df_aggregate(df, levels, name, sort=False):
+    return df.groupby(level=levels, sort=sort)[name].nunique()
 
 
 def _nunique_series_chunk(df, *index, **_ignored_):
@@ -896,9 +899,9 @@ def _compute_sum_of_squares(grouped, column):
     return base.apply(lambda x: (x ** 2).sum())
 
 
-def _agg_finalize(df, aggregate_funcs, finalize_funcs, level):
+def _agg_finalize(df, aggregate_funcs, finalize_funcs, level, sort=False):
     # finish the final aggregation level
-    df = _groupby_apply_funcs(df, funcs=aggregate_funcs, level=level)
+    df = _groupby_apply_funcs(df, funcs=aggregate_funcs, level=level, sort=sort)
 
     # and finalize the result
     result = collections.OrderedDict()
@@ -986,15 +989,21 @@ class _GroupBy(object):
         Passed to pandas.DataFrame.groupby()
     dropna: bool
         Whether to drop null values from groupby index
+    sort: bool, defult None
+        Passed along to aggregation methods. If allowed,
+        the output aggregation will have sorted keys.
     """
 
-    def __init__(self, df, by=None, slice=None, group_keys=True, dropna=None):
+    def __init__(
+        self, df, by=None, slice=None, group_keys=True, dropna=None, sort=None
+    ):
 
         assert isinstance(df, (DataFrame, Series))
         self.group_keys = group_keys
         self.obj = df
         # grouping key passed via groupby method
         self.index = _normalize_index(df, by)
+        self.sort = sort
 
         if isinstance(self.index, list):
             do_index_partition_align = all(
@@ -1092,6 +1101,7 @@ class _GroupBy(object):
             ),
             split_out=split_out,
             split_out_setup=split_out_on_index,
+            sort=self.sort,
         )
 
     def _cum_agg(self, token, chunk, aggregate, initial):
@@ -1346,6 +1356,7 @@ class _GroupBy(object):
             split_every=split_every,
             split_out=split_out,
             split_out_setup=split_out_on_index,
+            sort=self.sort,
         )
 
         if isinstance(self.obj, Series):
@@ -1404,6 +1415,7 @@ class _GroupBy(object):
             split_every=split_every,
             split_out=split_out,
             split_out_setup=split_out_on_index,
+            sort=self.sort,
         )
 
         if isinstance(self.obj, Series):
@@ -1519,6 +1531,7 @@ class _GroupBy(object):
             split_every=split_every,
             split_out=split_out,
             split_out_setup=split_out_on_index,
+            sort=self.sort,
         )
 
     @insert_meta_param_description(pad=12)
@@ -1704,9 +1717,13 @@ class DataFrameGroupBy(_GroupBy):
 
     def __getitem__(self, key):
         if isinstance(key, list):
-            g = DataFrameGroupBy(self.obj, by=self.index, slice=key, **self.dropna)
+            g = DataFrameGroupBy(
+                self.obj, by=self.index, slice=key, sort=self.sort, **self.dropna
+            )
         else:
-            g = SeriesGroupBy(self.obj, by=self.index, slice=key, **self.dropna)
+            g = SeriesGroupBy(
+                self.obj, by=self.index, slice=key, sort=self.sort, **self.dropna
+            )
 
         # error is raised from pandas
         g._meta = g._meta[key]
@@ -1788,6 +1805,7 @@ class SeriesGroupBy(_GroupBy):
             split_every=split_every,
             split_out=split_out,
             split_out_setup=split_out_on_index,
+            sort=self.sort,
         )
 
     @derived_from(pd.core.groupby.SeriesGroupBy)
