@@ -5,6 +5,11 @@ import copy
 import json
 import warnings
 
+try:
+    import cytoolz as toolz
+except ModuleNotFoundError:
+    import toolz
+
 import numpy as np
 import pandas as pd
 
@@ -27,28 +32,45 @@ from ...utils import UNKNOWN_CATEGORIES
 from .utils import Engine
 
 
-def _paths_to_cats(paths, scheme):
-    """Extract out fields and labels from directory names"""
-    # can be factored out in fastparquet
+def _paths_to_cats(paths, file_scheme):
+    """
+    Extract categorical fields and labels from hive- or drill-style paths.
+    FixMe: This has been pasted from https://github.com/dask/fastparquet/pull/471
+    Use fastparquet.api.paths_to_cats from fastparquet>0.3.2 instead.
+
+    Parameters
+    ----------
+    paths (Iterable[str]): file paths relative to root
+    file_scheme (str):
+
+    Returns
+    -------
+    cats (OrderedDict[str, List[Any]]): a dict of field names and their values
+    """
+    if file_scheme in ["simple", "flat", "other"]:
+        cats = {}
+        return cats
+
     cats = OrderedDict()
     raw_cats = OrderedDict()
+    s = ex_from_sep("/")
+    paths = toolz.unique(paths)
+    if file_scheme == "hive":
+        partitions = toolz.unique((k, v) for path in paths for k, v in s.findall(path))
+        for key, val in partitions:
+            cats.setdefault(key, set()).add(val_to_num(val))
+            raw_cats.setdefault(key, set()).add(val)
+    else:
+        i_val = toolz.unique(
+            (i, val) for path in paths for i, val in enumerate(path.split("/")[:-1])
+        )
+        for i, val in i_val:
+            key = "dir%i" % i
+            cats.setdefault(key, set()).add(val_to_num(val))
+            raw_cats.setdefault(key, set()).add(val)
 
-    for path in paths:
-        s = ex_from_sep("/")
-        if scheme == "hive":
-            partitions = s.findall(path)
-            for (key, val) in partitions:
-                cats.setdefault(key, set()).add(val_to_num(val))
-                raw_cats.setdefault(key, set()).add(val)
-        else:
-            for (i, val) in enumerate(path.split("/")[:-1]):
-                key = "dir%i" % i
-                cats.setdefault(key, set()).add(val_to_num(val))
-                raw_cats.setdefault(key, set()).add(val)
-
-    for (key, v) in cats.items():
-        # Check that no partition names map to the same value after
-        # transformation by val_to_num
+    for key, v in cats.items():
+        # Check that no partition names map to the same value after transformation by val_to_num
         raw = raw_cats[key]
         if len(v) != len(raw):
             conflicts_by_value = OrderedDict()
@@ -60,15 +82,21 @@ def _paths_to_cats(paths, scheme):
             raise ValueError("Partition names map to the same value: %s" % conflicts)
         vals_by_type = groupby_types(v)
 
-        # Check that all partition names map to the same type after
-        # transformation by val_to_num
+        # Check that all partition names map to the same type after transformation by val_to_num
         if len(vals_by_type) > 1:
             examples = [x[0] for x in vals_by_type.values()]
             warnings.warn(
-                "Partition names coerce to values of different"
-                " types, e.g. %s" % examples
+                "Partition names coerce to values of different types, e.g. %s"
+                % examples
             )
-    return {k: list(v) for k, v in cats.items()}
+
+    cats = OrderedDict([(key, list(v)) for key, v in cats.items()])
+    return cats
+
+
+paths_to_cats = (
+    _paths_to_cats  # FixMe: use fastparquet.api.paths_to_cats for fastparquet>0.3.2
+)
 
 
 def _determine_pf_parts(fs, paths, gather_statistics, **kwargs):
@@ -114,7 +142,7 @@ def _determine_pf_parts(fs, paths, gather_statistics, **kwargs):
                 scheme = get_file_scheme(fns)
                 pf = ParquetFile(paths[0], open_with=fs.open, **kwargs.get("file", {}))
                 pf.file_scheme = scheme
-                pf.cats = _paths_to_cats(fns, scheme)
+                pf.cats = paths_to_cats(fns, scheme)
                 parts = paths.copy()
     elif fs.isdir(paths[0]):
         # This is a directory, check for _metadata, then _common_metadata
@@ -148,7 +176,7 @@ def _determine_pf_parts(fs, paths, gather_statistics, **kwargs):
                 pf = ParquetFile(paths[0], open_with=fs.open, **kwargs.get("file", {}))
             scheme = get_file_scheme(fns)
             pf.file_scheme = scheme
-            pf.cats = _paths_to_cats(fns, scheme)
+            pf.cats = paths_to_cats(fns, scheme)
             parts = paths.copy()
     else:
         # There is only one file to read
@@ -269,25 +297,40 @@ class FastParquetEngine(Engine):
             # make statistics conform in layout
             for (i, row_group) in enumerate(pf.row_groups):
                 s = {"num-rows": row_group.num_rows, "columns": []}
-                for col in pf.columns:
+                for i_col, col in enumerate(pf.columns):
                     if col not in skip_cols:
                         d = {"name": col}
+                        cs_min = None
+                        cs_max = None
                         if pf.statistics["min"][col][0] is not None:
                             cs_min = pf.statistics["min"][col][i]
                             cs_max = pf.statistics["max"][col][i]
-                            if None in [cs_min, cs_max] and i == 0:
-                                skip_cols.add(col)
-                                continue
-                            if isinstance(cs_min, np.datetime64):
-                                cs_min = pd.Timestamp(cs_min)
-                                cs_max = pd.Timestamp(cs_max)
-                            d.update(
-                                {
-                                    "min": cs_min,
-                                    "max": cs_max,
-                                    "null_count": pf.statistics["null_count"][col][i],
-                                }
-                            )
+                        elif (
+                            dtypes[col] == "object"
+                            and row_group.columns[i_col].meta_data.statistics
+                        ):
+                            cs_min = row_group.columns[
+                                i_col
+                            ].meta_data.statistics.min_value
+                            cs_max = row_group.columns[
+                                i_col
+                            ].meta_data.statistics.max_value
+                            if isinstance(cs_min, (bytes, bytearray)):
+                                cs_min = cs_min.decode("utf-8")
+                                cs_max = cs_max.decode("utf-8")
+                        if None in [cs_min, cs_max] and i == 0:
+                            skip_cols.add(col)
+                            continue
+                        if isinstance(cs_min, np.datetime64):
+                            cs_min = pd.Timestamp(cs_min)
+                            cs_max = pd.Timestamp(cs_max)
+                        d.update(
+                            {
+                                "min": cs_min,
+                                "max": cs_max,
+                                "null_count": pf.statistics["null_count"][col][i],
+                            }
+                        )
                         s["columns"].append(d)
                 # Need this to filter out partitioned-on categorical columns
                 s["filter"] = fastparquet.api.filter_out_cats(row_group, filters)
@@ -340,7 +383,7 @@ class FastParquetEngine(Engine):
                 for ch in rg.columns:
                     ch.file_path = relpath
             pf.file_scheme = scheme
-            pf.cats = _paths_to_cats(fns, scheme)
+            pf.cats = paths_to_cats(fns, scheme)
             pf.fn = base
             return pf.to_pandas(columns, categories, index=index)
         else:
