@@ -12,7 +12,7 @@ hashers = []  # In decreasing performance order
 # - SHA1 is significantly faster than all other hashlib algorithms
 
 try:
-    import cityhash  # `pip install cityhash`
+    import cityhash  # `python -m pip install cityhash`
 except ImportError:
     pass
 else:
@@ -31,7 +31,7 @@ else:
         hashers.append(_hash_cityhash)
 
 try:
-    import xxhash  # `pip install xxhash`
+    import xxhash  # `python -m pip install xxhash`
 except ImportError:
     pass
 else:
@@ -45,7 +45,7 @@ else:
     hashers.append(_hash_xxhash)
 
 try:
-    import mmh3  # `pip install mmh3`
+    import mmh3  # `python -m pip install mmh3`
 except ImportError:
     pass
 else:
